@@ -91,7 +91,7 @@ int main(int argc, char *argv[])
                       QObject::tr("Use the option one time for each item you want to exclude"), QObject::tr("one item")});
     parser.addOption({{"z", "compression"}, QObject::tr("Compression format, valid choices: ")
                       + "lz4, lzo, gzip, xz, zstd", QObject::tr("format")});
-    parser.addOption({"shutdown", QObject::tr("Shutdown computer when done.")});
+    parser.addOption({QStringLiteral("shutdown"), QObject::tr("Shutdown computer when done.")});
 
     QStringList opts;
     opts.reserve(argc);
