@@ -115,11 +115,6 @@ bool Settings::checkTempDir()
     return true;
 }
 
-quint8 Settings::getDebianVersion() const
-{
-    return shell->getCmdOut(QStringLiteral("cat /etc/debian_version |cut -f1 -d'.'"), true).toUShort();
-}
-
 QString Settings::getEditor() const
 {
     QString editor = gui_editor;
@@ -243,7 +238,27 @@ void Settings::setVariables()
     live = isLive();
     users = listUsers();
     i686 = isi686();
-    debian_version = getDebianVersion();
+
+    QString distro_version_file;
+    if (QFileInfo::exists(QStringLiteral("/etc/antix-version")))
+        distro_version_file = QStringLiteral("/etc/antix-version");
+    else if (QFileInfo::exists(QStringLiteral("/etc/mx-version")))
+        distro_version_file = QStringLiteral("/etc/mx-version");
+
+    project_name = shell->getCmdOut(QStringLiteral("grep -oP '(?<=DISTRIB_ID=).*' /etc/lsb-release"));
+    project_name.replace(QLatin1String("\""), QLatin1String(""));
+    if (!distro_version_file.isEmpty()) {
+        distro_version = shell->getCmdOut("cut -f1 -d'_' " + distro_version_file);
+        distro_version.remove(QRegularExpression("^" + project_name + "_|^" + project_name + "-"));
+        full_distro_name = project_name + "-" + distro_version + "_" + QString(i686 ? QStringLiteral("386") : QStringLiteral("x64"));
+    } else {
+        distro_version = project_name + QStringLiteral("_") + QString(i686 ? QStringLiteral("386") : QStringLiteral("x64"));
+        full_distro_name = distro_version;
+    }
+    release_date = QDate::currentDate().toString(QStringLiteral("MMMM dd, yyyy"));
+    codename = shell->getCmdOut(QStringLiteral("grep -oP '(?<=DISTRIB_CODENAME=).*' /etc/lsb-release"));
+    codename.replace(QLatin1String("\""), QLatin1String(""));
+    boot_options = QStringLiteral("quiet");
 }
 
 // Create the output filename
@@ -495,7 +510,8 @@ void Settings::loadConfig()
                                                  qApp->applicationName() +
                                                  QStringLiteral("-exclude.list")).toString());
     snapshot_basename = settings.value(QStringLiteral("snapshot_basename"), "snapshot").toString();
-    make_chksum = settings.value(QStringLiteral("make_md5sum"), "no").toString() != QLatin1String("no");
+    make_md5sum = settings.value(QStringLiteral("make_md5sum"), "no").toString() != QLatin1String("no");
+    make_sha512sum = settings.value(QStringLiteral("make_sha512sum"), "no").toString() != QLatin1String("no");
     make_isohybrid = settings.value(QStringLiteral("make_isohybrid"), "yes").toString() == QLatin1String("yes");
     compression = settings.value(QStringLiteral("compression"), "zstd").toString();
     mksq_opt = settings.value(QStringLiteral("mksq_opt")).toString();
@@ -558,18 +574,24 @@ void Settings::processArgs(const QCommandLineParser &arg_parser)
         exit(EXIT_FAILURE);
     }
     reset_accounts = arg_parser.isSet(QStringLiteral("reset"));
-    if (reset_accounts)
+    if (reset_accounts) {
         excludeAll();
-    if (arg_parser.isSet(QStringLiteral("month")))
+    } if (arg_parser.isSet(QStringLiteral("month"))) {
         reset_accounts = true;
-    if (arg_parser.isSet(QStringLiteral("checksums")) || arg_parser.isSet(QStringLiteral("month")))
-        make_chksum = true;
-    if (arg_parser.isSet(QStringLiteral("no-checksums")))
-        make_chksum = false;
-    if (!arg_parser.value(QStringLiteral("compression")).isEmpty())
+    } if (arg_parser.isSet(QStringLiteral("checksums"))) {
+        make_sha512sum = true;
+        make_md5sum = true;
+    } if (arg_parser.isSet(QStringLiteral("month"))) {
+        make_sha512sum = true;
+        make_md5sum = false;
+    } if (arg_parser.isSet(QStringLiteral("no-checksums"))) {
+        make_sha512sum = false;
+        make_md5sum = false;
+    } if (!arg_parser.value(QStringLiteral("compression")).isEmpty()) {
         compression = arg_parser.value(QStringLiteral("compression"));
-    if (!arg_parser.value(QStringLiteral("compression-level")).isEmpty())
+    } if (!arg_parser.value(QStringLiteral("compression-level")).isEmpty()) {
         mksq_opt = arg_parser.value(QStringLiteral("compression-level"));
+    }
     selectKernel();
 }
 
